@@ -34,7 +34,7 @@ class ApplyFuncHandler(BaseHandler):
         qfn = skytools.quote_fqident(fn)
         qargs = [skytools.quote_literal(a) for a in args]
         sql = "select %s(%s);" % (qfn, ', '.join(qargs))
-        self.log.debug('applyfn.sql: %s' % sql)
+        self.log.debug('applyfn.sql: %s', sql)
         sql_queue_func(sql, qfunc_arg)
 
 #------------------------------------------------------------------------------
