@@ -14,7 +14,6 @@ import signal
 import sys
 import time
 
-import psycopg2
 import skytools
 import skytools.skylog
 
@@ -958,7 +957,7 @@ class DBScript(BaseScript):
         sql_retry_formula_a = self.cf.getint("sql_retry_formula_a", 1)
         sql_retry_formula_b = self.cf.getint("sql_retry_formula_b", 5)
         sql_retry_formula_cap = self.cf.getint("sql_retry_formula_cap", 60)
-        elist = exceptions or (psycopg2.OperationalError,)
+        elist = exceptions or tuple()
         stime = time.time()
         tried = 0
         dbc = None
