@@ -1,13 +1,29 @@
 #! /usr/bin/env python
 
-# this script simply mover events from one queue to another
+"""This script simply mover events from one queue to another.
 
-import sys, os, pgq, skytools
+Config parameters::
+
+    ## Parameters for queue_mover
+
+    src_db            = dbname=sourcedb
+    dst_db            = dbname=targetdb
+
+    dst_queue_name    = dest_queue
+"""
+
+import sys, os
+
+import pkgloader
+pkgloader.require('skytools', '3.0')
+
+import pgq
 
 class QueueMover(pgq.SerialConsumer):
+    __doc__ = __doc__
+    
     def __init__(self, args):
-        pgq.SerialConsumer.__init__(self, "queue_mover", "src_db", "dst_db", args)
-
+        pgq.SerialConsumer.__init__(self, "queue_mover3", "src_db", "dst_db", args)
         self.dst_queue_name = self.cf.get("dst_queue_name")
 
     def process_remote_batch(self, db, batch_id, ev_list, dst_db):
@@ -17,7 +33,6 @@ class QueueMover(pgq.SerialConsumer):
         for ev in ev_list:
             data = [ev.type, ev.data, ev.extra1, ev.extra2, ev.extra3, ev.extra4, ev.time]
             rows.append(data)
-            ev.tag_done()
         fields = ['type', 'data', 'extra1', 'extra2', 'extra3', 'extra4', 'time']
 
         # insert data
