@@ -1,12 +1,31 @@
 #! /usr/bin/env python
 
-# puts events into queue specified by field from 'queue_field' config parameter
+"""Puts events into queue specified by field from 'queue_field' config parameter.
 
-import sys, os, pgq, skytools
+Config parameters::
+
+    ## Parameters for queue_splitter
+
+    # database locations
+    src_db            = dbname=sourcedb_test
+    dst_db            = dbname=destdb_test
+
+    # event fields from  where target queue name is read
+    #queue_field       = extra1
+"""
+
+import sys
+
+import pkgloader
+pkgloader.require('skytools', '3.0')
+
+import pgq
 
 class QueueSplitter(pgq.SerialConsumer):
+    __doc__ = __doc__
+
     def __init__(self, args):
-        pgq.SerialConsumer.__init__(self, "queue_splitter", "src_db", "dst_db", args)
+        pgq.SerialConsumer.__init__(self, "queue_splitter3", "src_db", "dst_db", args)
 
     def process_remote_batch(self, db, batch_id, ev_list, dst_db):
         cache = {}
@@ -17,7 +36,6 @@ class QueueSplitter(pgq.SerialConsumer):
             if queue not in cache:
                 cache[queue] = []
             cache[queue].append(row)
-            ev.tag_done()
 
         # should match the composed row
         fields = ['type', 'data', 'extra1', 'extra2', 'extra3', 'extra4', 'time']
