@@ -22,12 +22,15 @@ Config::
 
 import sys
 
+import psycopg2
+
 import pkgloader
 pkgloader.require('skytools', '3.0')
 
 import pgq
 import skytools
 
+
 class SimpleLocalConsumer(pgq.LocalConsumer):
     __doc__ = __doc__
 
@@ -57,7 +60,8 @@ class SimpleLocalConsumer(pgq.LocalConsumer):
         payload['pgq.ev_extra4'] = ev.ev_extra4
 
         self.log.debug(self.dst_query, payload)
-        retries, curs = self.execute_with_retry('dst_db', self.dst_query, payload)
+        retries, curs = self.execute_with_retry('dst_db', self.dst_query, payload,
+                                                exceptions = (psycopg2.OperationalError,))
         if curs.statusmessage[:6] == 'SELECT':
             res = curs.fetchall()
             self.log.debug(res)
