@@ -1,5 +1,7 @@
 
 #include <postgres.h>
+
+#include "utils/elog.h"
 #include "funcapi.h"
 #include "mb/pg_wchar.h"
 #include "parser/keywords.h"
@@ -187,6 +189,7 @@ static int quote_literal(char *dst, const uint8 *src, int srclen)
 	const uint8 *cp1;
 	char	   *cp2;
 	int			wl;
+	bool		is_ext = false;
 
 	cp1 = src;
 	cp2 = dst;
@@ -196,6 +199,8 @@ static int quote_literal(char *dst, const uint8 *src, int srclen)
 	{
 		if ((wl = pg_mblen((const char *)cp1)) != 1)
 		{
+			if (wl > srclen)
+				wl = srclen;
 			srclen -= wl;
 
 			while (wl-- > 0)
@@ -203,10 +208,17 @@ static int quote_literal(char *dst, const uint8 *src, int srclen)
 			continue;
 		}
 
-		if (*cp1 == '\'')
+		if (*cp1 == '\'') {
 			*cp2++ = '\'';
-		if (*cp1 == '\\')
+		} else if (*cp1 == '\\') {
+			if (!is_ext) {
+				memmove(dst + 1, dst, cp2 - dst);
+				cp2++;
+				is_ext = true;
+				*dst = 'E';
+			}
 			*cp2++ = '\\';
+		}
 		*cp2++ = *cp1++;
 		srclen--;
 	}
@@ -216,6 +228,27 @@ static int quote_literal(char *dst, const uint8 *src, int srclen)
 	return cp2 - dst;
 }
 
+/* check if ident is keyword that needs quoting */
+static bool is_keyword(const char *ident)
+{
+	const ScanKeyword *kw;
+
+	/* do the lookup */
+#if PG_VERSION_NUM >= 80500
+	kw = ScanKeywordLookup(ident, ScanKeywords, NumScanKeywords);
+#else
+	kw = ScanKeywordLookup(ident);
+#endif
+
+	/* unreserved? */
+#if PG_VERSION_NUM >= 80300
+	if (kw && kw->category == UNRESERVED_KEYWORD)
+		return false;
+#endif
+
+	/* found anything? */
+	return kw != NULL;
+}
 
 /*
  * slon_quote_identifier                     - Quote an identifier only if needed
@@ -266,24 +299,9 @@ quote_ident(char *dst, const uint8 *src, int srclen)
                         nquotes++;
         }
 
-        if (safe)
-        {
-                /*
-                 * Check for keyword.  This test is overly strong, since many of
-                 * the "keywords" known to the parser are usable as column names,
-                 * but the parser doesn't provide any easy way to test for whether
-                 * an identifier is safe or not... so be safe not sorry.
-                 *
-                 * Note: ScanKeywordLookup() does case-insensitive comparison, but
-                 * that's fine, since we already know we have all-lower-case.
-                 */
-#if defined(PG_VERSION_NUM) && PG_VERSION_NUM >= 90000
-		if (ScanKeywordLookup(ident, ScanKeywords, NumScanKeywords) != NULL)
-#else
-		if (ScanKeywordLookup(ident) != NULL)
-#endif
-
-                        safe = false;
+        if (safe) {
+            if (is_keyword(ident))
+                safe = false;
         }
 
 		optr = dst;
