@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2007 Marko Kreen, Skype Technologies OÜ
  *
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  *
@@ -39,19 +39,18 @@ Datum pgq_logtriga(PG_FUNCTION_ARGS);
  *    ev_extra1 - table name
  */
 
-Datum
-pgq_logtriga(PG_FUNCTION_ARGS)
+Datum pgq_logtriga(PG_FUNCTION_ARGS)
 {
 	TriggerData *tg;
-	PgqTriggerEvent	ev;
+	PgqTriggerEvent ev;
 
 	/*
 	 * Get the trigger call context
 	 */
 	if (!CALLED_AS_TRIGGER(fcinfo))
-		elog(ERROR, "pgq.logutriga not called as trigger");
+		elog(ERROR, "pgq.logtriga not called as trigger");
 
-	tg = (TriggerData *) (fcinfo->context);
+	tg = (TriggerData *)(fcinfo->context);
 
 	if (!TRIGGER_FIRED_AFTER(tg->tg_event))
 		elog(ERROR, "pgq.logtriga must be fired AFTER");
@@ -67,13 +66,13 @@ pgq_logtriga(PG_FUNCTION_ARGS)
 
 	pgq_prepare_event(&ev, tg, false);
 
-	appendStringInfoChar(ev.ev_type, ev.op_type);
-	appendStringInfoString(ev.ev_extra1, ev.info->table_name);
+	appendStringInfoChar(ev.field[EV_TYPE], ev.op_type);
+	appendStringInfoString(ev.field[EV_EXTRA1], ev.info->table_name);
 
 	/*
 	 * create sql and insert if interesting
 	 */
-	if (pgqtriga_make_sql(&ev, tg, ev.ev_data))
+	if (pgqtriga_make_sql(&ev, ev.field[EV_DATA]))
 		pgq_insert_tg_event(&ev);
 
 	if (SPI_finish() < 0)
@@ -82,4 +81,3 @@ pgq_logtriga(PG_FUNCTION_ARGS)
 skip_it:
 	return PointerGetDatum(NULL);
 }
-
