@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2007 Marko Kreen, Skype Technologies OÜ
  *
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  *
@@ -39,6 +39,7 @@ StringInfo pgq_init_varbuf(void)
 
 Datum pgq_finish_varbuf(StringInfo buf)
 {
+	if (!buf) return (Datum)0;
 	SET_VARSIZE(buf->data, buf->len);
 	return PointerGetDatum(buf->data);
 }
@@ -53,7 +54,7 @@ bool pgq_strlist_contains(const char *liststr, const char *str)
 {
 	int c, len = strlen(str);
 	const char *p, *listpos = liststr;
-	
+
 loop:
 	/* find string fragment, later check if actual token */
 	p = strstr(listpos, str);
@@ -95,10 +96,9 @@ static int pgq_urlencode(char *dst, const uint8 *src, int srclen)
 		if (c == ' ') {
 			*p++ = '+';
 		} else if ((c >= '0' && c <= '9')
-			|| (c >= 'A' && c <= 'Z')
-			|| (c >= 'a' && c <= 'z')
-			|| c == '_' || c == '.')
-		{
+			   || (c >= 'A' && c <= 'Z')
+			   || (c >= 'a' && c <= 'z')
+			   || c == '_' || c == '.' || c == '-') {
 			*p++ = c;
 		} else {
 			*p++ = '%';
@@ -143,12 +143,32 @@ static int pgq_quote_literal(char *dst, const uint8 *src, int srclen)
 	return cp2 - dst;
 }
 
+/* check if ident is keyword that needs quoting */
+static bool is_keyword(const char *ident)
+{
+	const ScanKeyword *kw;
+
+	/* do the lookup */
+#if PG_VERSION_NUM >= 80500
+	kw = ScanKeywordLookup(ident, ScanKeywords, NumScanKeywords);
+#else
+	kw = ScanKeywordLookup(ident);
+#endif
+
+	/* unreserved? */
+#if PG_VERSION_NUM >= 80300
+	if (kw && kw->category == UNRESERVED_KEYWORD)
+		return false;
+#endif
+
+	/* found anything? */
+	return kw != NULL;
+}
 
 /*
- * slon_quote_identifier - Quote an identifier only if needed
+ * pgq_quote_ident - Quote an identifier only if needed
  */
-static int
-pgq_quote_ident(char *dst, const uint8 *src, int srclen)
+static int pgq_quote_ident(char *dst, const uint8 *src, int srclen)
 {
 	/*
 	 * Can avoid quoting if ident starts with a lowercase letter or
@@ -156,10 +176,10 @@ pgq_quote_ident(char *dst, const uint8 *src, int srclen)
 	 * underscores, *and* is not any SQL keyword.  Otherwise, supply
 	 * quotes.
 	 */
-	int                     nquotes = 0;
-	bool            safe;
+	int nquotes = 0;
+	bool safe;
 	const char *ptr;
-	char       *optr;
+	char *optr;
 	char ident[NAMEDATALEN + 1];
 
 	/* expect idents be not bigger than NAMEDATALEN */
@@ -174,36 +194,19 @@ pgq_quote_ident(char *dst, const uint8 *src, int srclen)
 	 */
 	safe = ((ident[0] >= 'a' && ident[0] <= 'z') || ident[0] == '_');
 
-	for (ptr = ident; *ptr; ptr++)
-	{
-		char            ch = *ptr;
+	for (ptr = ident; *ptr; ptr++) {
+		char ch = *ptr;
 
-		if ((ch >= 'a' && ch <= 'z') ||
-			(ch >= '0' && ch <= '9') ||
-			(ch == '_'))
-			continue; /* okay */
+		if ((ch >= 'a' && ch <= 'z') || (ch >= '0' && ch <= '9') || (ch == '_'))
+			continue;	/* okay */
 
 		safe = false;
 		if (ch == '"')
 			nquotes++;
 	}
 
-	if (safe)
-	{
-		/*
-		 * Check for keyword.  This test is overly strong, since many of
-		 * the "keywords" known to the parser are usable as column names,
-		 * but the parser doesn't provide any easy way to test for whether
-		 * an identifier is safe or not... so be safe not sorry.
-		 *
-		 * Note: ScanKeywordLookup() does case-insensitive comparison, but
-		 * that's fine, since we already know we have all-lower-case.
-		 */
-#if defined(PG_VERSION_NUM) && PG_VERSION_NUM >= 90000
-		if (ScanKeywordLookup(ident, ScanKeywords, NumScanKeywords) != NULL)
-#else
-		if (ScanKeywordLookup(ident) != NULL)
-#endif
+	if (safe) {
+		if (is_keyword(ident))
 			safe = false;
 	}
 
@@ -211,9 +214,8 @@ pgq_quote_ident(char *dst, const uint8 *src, int srclen)
 	if (!safe)
 		*optr++ = '"';
 
-	for (ptr = ident; *ptr; ptr++)
-	{
-		char            ch = *ptr;
+	for (ptr = ident; *ptr; ptr++) {
+		char ch = *ptr;
 
 		if (ch == '"')
 			*optr++ = '"';
@@ -239,10 +241,7 @@ static void finish_append(StringInfo buf, int final_len)
 }
 
 
-static void
-tbuf_encode_data(StringInfo buf,
-				 const uint8 *data, int len,
-				 enum PgqEncode encoding)
+static void tbuf_encode_data(StringInfo buf, const uint8 *data, int len, enum PgqEncode encoding)
 {
 	int dlen = 0;
 	char *dst;
@@ -270,13 +269,9 @@ tbuf_encode_data(StringInfo buf,
 	finish_append(buf, dlen);
 }
 
-void
-pgq_encode_cstring(StringInfo tbuf,
-					const char *str,
-					enum PgqEncode encoding)
+void pgq_encode_cstring(StringInfo tbuf, const char *str, enum PgqEncode encoding)
 {
 	if (str == NULL)
 		elog(ERROR, "tbuf_encode_cstring: NULL");
 	tbuf_encode_data(tbuf, (const uint8 *)str, strlen(str), encoding);
 }
-
