@@ -8,7 +8,4 @@ enum PgqEncode {
 StringInfo pgq_init_varbuf(void);
 Datum pgq_finish_varbuf(StringInfo buf);
 bool pgq_strlist_contains(const char *liststr, const char *str);
-void pgq_encode_cstring(StringInfo tbuf,
-						const char *str,
-						enum PgqEncode encoding);
-
+void pgq_encode_cstring(StringInfo tbuf, const char *str, enum PgqEncode encoding);
