@@ -1,7 +1,3 @@
-\set ECHO off
-\i pgq_ext.sql
-\set ECHO all
-
 --
 -- test batch tracking
 --
